use strict;
use Benchmark;
use Pg;
use DBI;
my $iLoop = 5000;
my $sDt  = '2001-12-18';
my $sSel = 'SELECT TITLE, CREDT FROM ALBUM ORDER BY TITLE';
my @aPg;
{
$aPg[0] = new Benchmark;
    my $oConn = Pg::connectdb('host=lins dbname=test user=scott password=tiger');
    die $oConn->errorMessage if($oConn->status != PGRES_CONNECTION_OK);
    $oConn->exec('begin');
    $oConn->exec('DELETE FROM ALBUM');
    $oConn->exec('end');
$aPg[1] = new Benchmark;
    $oConn->exec('begin');
    for(my $i=0;$i<$iLoop;$i++) {
        $oConn->exec("INSERT INTO ALBUM(TITLE,CREDT)VALUES('TTL-$i','$sDt')");
    }
    $oConn->exec('end');
$aPg[2] = new Benchmark;
    my $result = $oConn->exec($sSel);
    my $sLine;
    while (my @row = $result->fetchrow) { $sLine = join(':', @row); }
$aPg[3] = new Benchmark;
}
my @aDb;
{
$aDb[0] = new Benchmark;
    my $hDb = DBI->connect('dbi:Pg:host=lins;dbname=test',
        'scott', 'tiger', {RaiseError => 1, AutoCommit=>0});
    $hDb->commit;
    $hDb->do('DELETE FROM ALBUM');
$aDb[1] = new Benchmark;
    for(my $i=0;$i<$iLoop;$i++) {
        $hDb->do("INSERT INTO ALBUM(TITLE,CREDT)VALUES('TTL-$i','$sDt')");
    }
    $hDb->commit;
$aDb[2]  = new Benchmark;
    my $hSt = $hDb->prepare( $sSel );
    $hSt->execute();
    my $sLine;
    while(my $raData=$hSt->fetchrow_arrayref()){ $sLine = join(':', @$raData);}
    $hSt->finish;
    $hDb->disconnect;
$aDb[3] = new Benchmark;
}

my @aDbP;
$aDbP[0] = new Benchmark;
{
    my $hDb = DBI->connect('dbi:Pg:host=lins;dbname=test',
        'scott', 'tiger', {RaiseError => 1, AutoCommit=>0});
    $hDb->commit;
    $hDb->do('DELETE FROM ALBUM');
$aDbP[1] = new Benchmark;
    my $hStI = $hDb->prepare(q/INSERT INTO ALBUM(TITLE,CREDT)VALUES(?, ?)/);
    for(my $i=0;$i<$iLoop;$i++) {$hStI->execute("TTL-$i", $sDt); }
    $hDb->commit;
$aDbP[2]  = new Benchmark;
    my $hSt = $hDb->prepare($sSel);
    $hSt->execute();
    my $sLine;
    while(my $raData=$hSt->fetchrow_arrayref()){$sLine = join(':', @$raData); }
    $hSt->finish;
    $hDb->disconnect;
$aDbP[3] = new Benchmark;
}
print "Pg\n",
      "1:",timestr(timediff($aPg[1], $aPg[0])),"\n",
      "2:",timestr(timediff($aPg[2], $aPg[0])),"\n",
      "3:",timestr(timediff($aPg[3], $aPg[0])),"\n",
      "DBI-1\n",
      "1:",timestr(timediff($aDb[1], $aDb[0])),"\n",
      "2:",timestr(timediff($aDb[2], $aDb[0])),"\n",
      "3:",timestr(timediff($aDb[3], $aDb[0])),"\n",
      "DBI-2\n",
      "1:",timestr(timediff($aDbP[1], $aDbP[0])),"\n",
      "2:",timestr(timediff($aDbP[2], $aDbP[0])),"\n",
      "3:",timestr(timediff($aDbP[3], $aDbP[0])),"\n";
